@@ -10,30 +10,28 @@
 """The main pgAdmin module. This handles the application initialisation tasks,
 such as setup of logging, dynamic loading of modules etc."""
 import logging
-import os, sys
+import os
+import sys
 from collections import defaultdict
 from importlib import import_module
 
 from flask import Flask, abort, request, current_app, session, url_for
-from flask_babel import Babel, gettext
+from flask_babelex import Babel, gettext
 from flask_login import user_logged_in, user_logged_out
-from flask_security import Security, SQLAlchemyUserDatastore, current_user
 from flask_mail import Mail
+from flask_paranoid import Paranoid
+from flask_security import Security, SQLAlchemyUserDatastore, current_user
 from flask_security.utils import login_user
 from werkzeug.datastructures import ImmutableDict
-from flask_paranoid import Paranoid
-
-from pgadmin.utils import PgAdminModule, driver
-from pgadmin.utils.versioned_template_loader import VersionedTemplateLoader
-from pgadmin.utils.session import create_session_interface
 from werkzeug.local import LocalProxy
 from werkzeug.utils import find_modules
 
-from pgadmin.utils.preferences import Preferences
-
 from pgadmin.model import db, Role, Server, ServerGroup, \
     User, Keys, Version, SCHEMA_VERSION as CURRENT_SCHEMA_VERSION
-
+from pgadmin.utils import PgAdminModule, driver
+from pgadmin.utils.preferences import Preferences
+from pgadmin.utils.session import create_session_interface, pga_unauthorised
+from pgadmin.utils.versioned_template_loader import VersionedTemplateLoader
 
 # If script is running under python3, it will not have the xrange function
 # defined
@@ -168,7 +166,6 @@ current_blueprint = LocalProxy(_find_blueprint)
 
 
 def create_app(app_name=None):
-
     # Configuration settings
     import config
     if not app_name:
@@ -216,8 +213,10 @@ def create_app(app_name=None):
     logger.setLevel(logging.INFO)
 
     # Set SQLITE_PATH to TEST_SQLITE_PATH while running test cases
-    if "PGADMIN_TESTING_MODE" in os. environ and \
-                    os.environ["PGADMIN_TESTING_MODE"] == "1":
+    if (
+        'PGADMIN_TESTING_MODE' in os.environ and
+        os.environ['PGADMIN_TESTING_MODE'] == '1'
+    ):
         config.SQLITE_PATH = config.TEST_SQLITE_PATH
 
     # Ensure the various working directories exist
@@ -280,7 +279,9 @@ def create_app(app_name=None):
             elif hasattr(session, 'PGADMIN_LANGUAGE'):
                 language = getattr(session, 'PGADMIN_LANGUAGE', language)
             elif hasattr(request.cookies, 'PGADMIN_LANGUAGE'):
-                language = getattr(request.cookies, 'PGADMIN_LANGUAGE', language)
+                language = getattr(
+                    request.cookies, 'PGADMIN_LANGUAGE', language
+                )
 
         return language
 
@@ -288,10 +289,10 @@ def create_app(app_name=None):
     # Setup authentication
     ##########################################################################
 
-    app.config['SQLALCHEMY_DATABASE_URI'] = u'sqlite:///{0}?timeout={1}'.format(
-        config.SQLITE_PATH.replace(u'\\', u'/'),
-        getattr(config, 'SQLITE_TIMEOUT', 500)
-    )
+    app.config['SQLALCHEMY_DATABASE_URI'] = u'sqlite:///{0}?timeout={1}' \
+        .format(config.SQLITE_PATH.replace(u'\\', u'/'),
+                getattr(config, 'SQLITE_TIMEOUT', 500)
+                )
 
     # Create database connection object and mailer
     db.init_app(app)
@@ -332,18 +333,27 @@ def create_app(app_name=None):
     # Setup security
     ##########################################################################
     with app.app_context():
-        config.CSRF_SESSION_KEY = Keys.query.filter_by(name = 'CSRF_SESSION_KEY').first().value
-        config.SECRET_KEY = Keys.query.filter_by(name = 'SECRET_KEY').first().value
-        config.SECURITY_PASSWORD_SALT = Keys.query.filter_by(name = 'SECURITY_PASSWORD_SALT').first().value
+        config.CSRF_SESSION_KEY = Keys.query.filter_by(
+            name='CSRF_SESSION_KEY').first().value
+        config.SECRET_KEY = Keys.query.filter_by(
+            name='SECRET_KEY').first().value
+        config.SECURITY_PASSWORD_SALT = Keys.query.filter_by(
+            name='SECURITY_PASSWORD_SALT').first().value
 
     # Update the app.config with proper security keyes for signing CSRF data,
     # signing cookies, and the SALT for hashing the passwords.
-    app.config.update(dict(CSRF_SESSION_KEY=config.CSRF_SESSION_KEY))
-    app.config.update(dict(SECRET_KEY=config.SECRET_KEY))
-    app.config.update(dict(SECURITY_PASSWORD_SALT=config.SECURITY_PASSWORD_SALT))
+    app.config.update(dict({
+        'CSRF_SESSION_KEY': config.CSRF_SESSION_KEY,
+        'SECRET_KEY': config.SECRET_KEY,
+        'SECURITY_PASSWORD_SALT': config.SECURITY_PASSWORD_SALT,
+        'SESSION_COOKIE_DOMAIN': config.SESSION_COOKIE_DOMAIN
+    }))
 
     security.init_app(app, user_datastore)
 
+    # register custom unauthorised handler.
+    app.login_manager.unauthorized_handler(pga_unauthorised)
+
     app.session_interface = create_session_interface(app)
 
     # Make the Session more secure against XSS & CSRF when running in web mode
@@ -376,7 +386,6 @@ def create_app(app_name=None):
             if user_languages and language:
                 language = user_languages.set(language)
 
-
     ##########################################################################
     # Register any local servers we can discover
     ##########################################################################
@@ -396,26 +405,28 @@ def create_app(app_name=None):
             servergroup_id = servergroup.id
 
         '''Add a server to the config database'''
-        def add_server(user_id, servergroup_id, name, superuser, port, discovery_id, comment):
-        # Create a server object if needed, and store it.
+
+        def add_server(user_id, servergroup_id, name, superuser, port,
+                       discovery_id, comment):
+            # Create a server object if needed, and store it.
             servers = Server.query.filter_by(
                 user_id=user_id,
                 discovery_id=svr_discovery_id
             ).order_by("id")
 
             if servers.count() > 0:
-                return;
+                return
 
             svr = Server(user_id=user_id,
-                            servergroup_id=servergroup_id,
-                            name=name,
-                            host='localhost',
-                            port=port,
-                            maintenance_db='postgres',
-                            username=superuser,
-                            ssl_mode='prefer',
-                            comment=svr_comment,
-                            discovery_id=discovery_id)
+                         servergroup_id=servergroup_id,
+                         name=name,
+                         host='localhost',
+                         port=port,
+                         maintenance_db='postgres',
+                         username=superuser,
+                         ssl_mode='prefer',
+                         comment=svr_comment,
+                         discovery_id=discovery_id)
 
             db.session.add(svr)
             db.session.commit()
@@ -427,7 +438,7 @@ def create_app(app_name=None):
 
             try:
                 proc_arch64 = os.environ['PROCESSOR_ARCHITEW6432'].lower()
-            except:
+            except Exception as e:
                 proc_arch64 = None
 
             if proc_arch == 'x86' and not proc_arch64:
@@ -457,7 +468,8 @@ def create_app(app_name=None):
                             svr_port = winreg.QueryValueEx(inst_key, 'Port')[0]
                             svr_discovery_id = inst_id
                             svr_comment = gettext(
-                                "Auto-detected %s installation with the data directory at %s" % (
+                                "Auto-detected %s installation with the data "
+                                "directory at %s" % (
                                     winreg.QueryValueEx(
                                         inst_key, 'Display Name'
                                     )[0],
@@ -474,7 +486,7 @@ def create_app(app_name=None):
                             )
 
                             inst_key.Close()
-                    except:
+                    except Exception as e:
                         pass
         else:
             # We use the postgres-winreg.ini file on non-Windows
@@ -491,7 +503,10 @@ def create_app(app_name=None):
 
             # Loop the sections, and get the data from any that are PG or PPAS
             for section in sections:
-                if section.startswith('PostgreSQL/') or section.startswith('EnterpriseDB/'):
+                if (
+                    section.startswith('PostgreSQL/') or
+                    section.startswith('EnterpriseDB/')
+                ):
                     svr_name = registry.get(section, 'Description')
                     svr_superuser = registry.get(section, 'Superuser')
                     svr_port = registry.getint(section, 'Port')
@@ -501,13 +516,17 @@ def create_app(app_name=None):
                     if hasattr(str, 'decode'):
                         description = description.decode('utf-8')
                         data_directory = data_directory.decode('utf-8')
-                    svr_comment = gettext(u"Auto-detected %s installation with the data directory at %s" % (
-                        description,
-                        data_directory
-                    ))
-                    add_server(user_id, servergroup_id, svr_name, svr_superuser, svr_port, svr_discovery_id, svr_comment)
+                    svr_comment = gettext(u"Auto-detected %s installation "
+                                          u"with the data directory at %s" % (
+                                              description,
+                                              data_directory
+                                          )
+                                          )
+                    add_server(user_id, servergroup_id, svr_name,
+                               svr_superuser, svr_port, svr_discovery_id,
+                               svr_comment)
 
-        except:
+        except Exception as e:
             pass
 
     @user_logged_in.connect_via(app)
@@ -534,7 +553,8 @@ def create_app(app_name=None):
         # mode, and it's not a help file request.
         if not config.SERVER_MODE and app.PGADMIN_KEY != '':
             if (
-                (not 'key' in request.args or request.args['key'] != app.PGADMIN_KEY) and
+                ('key' not in request.args or
+                 request.args['key'] != app.PGADMIN_KEY) and
                 request.cookies.get('PGADMIN_KEY') != app.PGADMIN_KEY and
                 request.endpoint != 'help.static'
             ):
@@ -547,7 +567,8 @@ def create_app(app_name=None):
             # that'll through a nice 500 error for us.
             if user is None:
                 app.logger.error(
-                    'The desktop user %s was not found in the configuration database.'
+                    'The desktop user %s was not found in the configuration '
+                    'database.'
                     % config.DESKTOP_USER
                 )
                 abort(401)
@@ -556,7 +577,13 @@ def create_app(app_name=None):
     @app.after_request
     def after_request(response):
         if 'key' in request.args:
-            response.set_cookie('PGADMIN_KEY', value=request.args['key'])
+            domain = dict()
+            if config.COOKIE_DEFAULT_DOMAIN and \
+                    config.COOKIE_DEFAULT_DOMAIN != 'localhost':
+                domain['domain'] = config.COOKIE_DEFAULT_DOMAIN
+            response.set_cookie('PGADMIN_KEY', value=request.args['key'],
+                                path=config.COOKIE_DEFAULT_PATH,
+                                **domain)
 
         return response
 
@@ -564,7 +591,7 @@ def create_app(app_name=None):
     # Minify output
     ##########################################################################
     # HTMLMIN doesn't work with Python 2.6.
-    if not config.DEBUG and sys.version_info >= (2,7):
+    if not config.DEBUG and sys.version_info >= (2, 7):
         from flask_htmlmin import HTMLMIN
         HTMLMIN(app)
 
