@@ -9,26 +9,26 @@
 
 """Implements the Database Node"""
 
-import simplejson as json
 import re
 from functools import wraps
 
-import pgadmin.browser.server_groups.servers as servers
+import simplejson as json
 from flask import render_template, current_app, request, jsonify
-from flask_babel import gettext as _
+from flask_babelex import gettext as _
+
+import pgadmin.browser.server_groups.servers as servers
+from config import PG_DEFAULT_DRIVER
 from pgadmin.browser.collection import CollectionNodeModule
 from pgadmin.browser.server_groups.servers.databases.utils import \
     parse_sec_labels_from_db, parse_variables_from_db
 from pgadmin.browser.server_groups.servers.utils import parse_priv_from_db, \
     parse_priv_to_db
 from pgadmin.browser.utils import PGChildNodeView
+from pgadmin.utils.ajax import gone
 from pgadmin.utils.ajax import make_json_response, \
     make_response as ajax_response, internal_server_error, unauthorized
-from pgadmin.utils.ajax import gone
 from pgadmin.utils.driver import get_driver
 
-from config import PG_DEFAULT_DRIVER
-
 
 class DatabaseModule(CollectionNodeModule):
     NODE_TYPE = 'database'
@@ -86,6 +86,7 @@ class DatabaseModule(CollectionNodeModule):
         """
         return False
 
+
 blueprint = DatabaseModule(__name__)
 
 
@@ -105,20 +106,52 @@ class DatabaseView(PGChildNodeView):
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
             {'get': 'list', 'post': 'create'}
         ],
-        'nodes': [{'get': 'node'}, {'get': 'nodes'}],
-        'get_databases': [{'get': 'get_databases'}, {'get': 'get_databases'}],
-        'sql': [{'get': 'sql'}],
-        'msql': [{'get': 'msql'}, {'get': 'msql'}],
-        'stats': [{'get': 'statistics'}, {'get': 'statistics'}],
-        'dependency': [{'get': 'dependencies'}],
-        'dependent': [{'get': 'dependents'}],
-        'children': [{'get': 'children'}],
-        'connect': [{
-            'get': 'connect_status', 'post': 'connect', 'delete': 'disconnect'
-        }],
-        'get_encodings': [{'get': 'get_encodings'}, {'get': 'get_encodings'}],
-        'get_ctypes': [{'get': 'get_ctypes'}, {'get': 'get_ctypes'}],
-        'vopts': [{}, {'get': 'variable_options'}]
+        'nodes': [
+            {'get': 'node'},
+            {'get': 'nodes'}
+        ],
+        'get_databases': [
+            {'get': 'get_databases'},
+            {'get': 'get_databases'}
+        ],
+        'sql': [
+            {'get': 'sql'}
+        ],
+        'msql': [
+            {'get': 'msql'},
+            {'get': 'msql'}
+        ],
+        'stats': [
+            {'get': 'statistics'},
+            {'get': 'statistics'}
+        ],
+        'dependency': [
+            {'get': 'dependencies'}
+        ],
+        'dependent': [
+            {'get': 'dependents'}
+        ],
+        'children': [
+            {'get': 'children'}
+        ],
+        'connect': [
+            {
+                'get': 'connect_status',
+                'post': 'connect',
+                'delete': 'disconnect'
+            }
+        ],
+        'get_encodings': [
+            {'get': 'get_encodings'},
+            {'get': 'get_encodings'}
+        ],
+        'get_ctypes': [
+            {'get': 'get_ctypes'},
+            {'get': 'get_ctypes'}
+        ],
+        'vopts': [
+            {}, {'get': 'variable_options'}
+        ]
     })
 
     def check_precondition(action=None):
@@ -132,7 +165,11 @@ class DatabaseView(PGChildNodeView):
             @wraps(f)
             def wrapped(self, *args, **kwargs):
 
-                self.manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(kwargs['sid'])
+                self.manager = get_driver(
+                    PG_DEFAULT_DRIVER
+                ).connection_manager(
+                    kwargs['sid']
+                )
                 if self.manager is None:
                     return gone(errormsg="Could not find the server.")
 
@@ -152,7 +189,9 @@ class DatabaseView(PGChildNodeView):
                     self.conn = self.manager.connection()
 
                 # set template path for sql scripts
-                self.template_path = 'databases/sql/#{0}#'.format(self.manager.version)
+                self.template_path = 'databases/sql/#{0}#'.format(
+                    self.manager.version
+                )
 
                 return f(self, *args, **kwargs)
 
@@ -162,20 +201,21 @@ class DatabaseView(PGChildNodeView):
 
     @check_precondition(action="list")
     def list(self, gid, sid):
-        last_system_oid = 0 if self.blueprint.show_system_objects else \
-            (self.manager.db_info[self.manager.did])['datlastsysoid'] \
-            if self.manager.db_info is not None and \
-            self.manager.did in self.manager.db_info else 0
+        last_system_oid = self.retrieve_last_system_oid()
 
         db_disp_res = None
         params = None
         if self.manager and self.manager.db_res:
-            db_disp_res = ", ".join(['%s'] * len(self.manager.db_res.split(',')))
+            db_disp_res = ", ".join(
+                ['%s'] * len(self.manager.db_res.split(','))
+            )
             params = tuple(self.manager.db_res.split(','))
 
         SQL = render_template(
             "/".join([self.template_path, 'properties.sql']),
-            conn=self.conn, last_system_oid=last_system_oid, db_restrictions=db_disp_res
+            conn=self.conn,
+            last_system_oid=last_system_oid,
+            db_restrictions=db_disp_res
         )
         status, res = self.conn.execute_dict(SQL, params)
 
@@ -187,20 +227,29 @@ class DatabaseView(PGChildNodeView):
             status=200
         )
 
+    def retrieve_last_system_oid(self):
+        last_system_oid = 0
+        if self.blueprint.show_system_objects:
+            last_system_oid = 0
+        elif (
+            self.manager.db_info is not None and
+            self.manager.did in self.manager.db_info
+        ):
+            last_system_oid = (self.manager.db_info[self.manager.did])[
+                'datlastsysoid']
+        return last_system_oid
+
     def get_nodes(self, gid, sid, show_system_templates=False):
         res = []
-        last_system_oid = 0 if self.blueprint.show_system_objects or \
-            show_system_templates else (
-                (self.manager.db_info[self.manager.did])['datlastsysoid'] \
-                if self.manager.db_info is not None and \
-                self.manager.did in self.manager.db_info else 0
-            )
+        last_system_oid = self.retrieve_last_system_oid()
         server_node_res = self.manager
 
         db_disp_res = None
         params = None
         if server_node_res and server_node_res.db_res:
-            db_disp_res = ", ".join(['%s']*len(server_node_res.db_res.split(',')))
+            db_disp_res = ", ".join(
+                ['%s'] * len(server_node_res.db_res.split(','))
+            )
             params = tuple(server_node_res.db_res.split(','))
         SQL = render_template(
             "/".join([self.template_path, 'nodes.sql']),
@@ -218,7 +267,7 @@ class DatabaseView(PGChildNodeView):
                 connected = True
                 canDrop = canDisConn = False
             else:
-                conn = self.manager.connection(dbname,did=row['did'])
+                conn = self.manager.connection(dbname, did=row['did'])
                 connected = conn.connected()
                 canDrop = canDisConn = True
 
@@ -276,13 +325,15 @@ class DatabaseView(PGChildNodeView):
             else:
                 conn = self.manager.connection(row['name'])
                 connected = conn.connected()
+            icon_css_class = "pg-icon-database"
+            if not connected:
+                icon_css_class = "icon-database-not-connected"
             return make_json_response(
                 data=self.blueprint.generate_browser_node(
                     row['did'],
                     sid,
                     row['name'],
-                    icon="icon-database-not-connected" if not connected \
-                        else "pg-icon-database",
+                    icon=icon_css_class,
                     connected=connected,
                     spcname=row['spcname'],
                     allowConn=row['datallowconn'],
@@ -495,7 +546,8 @@ class DatabaseView(PGChildNodeView):
         if 'datacl' in data:
             data['datacl'] = parse_priv_to_db(data['datacl'], 'DATABASE')
 
-        # The below SQL will execute rest DMLs because we cannot execute CREATE with any other
+        # The below SQL will execute rest DMLs because we cannot execute
+        # CREATE with any other
         SQL = render_template(
             "/".join([self.template_path, 'grant.sql']),
             data=data, conn=self.conn
@@ -534,7 +586,7 @@ class DatabaseView(PGChildNodeView):
             )
         )
 
-    @check_precondition(action="update")
+    @check_precondition(action='update')
     def update(self, gid, sid, did):
         """Update the database."""
 
@@ -543,13 +595,12 @@ class DatabaseView(PGChildNodeView):
         )
 
         # Generic connection for offline updates
-        conn = self.manager.connection(conn_id="db_offline_update")
+        conn = self.manager.connection(conn_id='db_offline_update')
         status, errmsg = conn.connect()
         if not status:
             current_app.logger.error(
-                "Could not create database connection for offline updates\nErr: {0}".format(
-                    errmsg
-                )
+                "Could not create database connection for offline updates\n"
+                "Err: {0}".format(errmsg)
             )
             return internal_server_error(errmsg)
 
@@ -566,7 +617,7 @@ class DatabaseView(PGChildNodeView):
 
             if len(rset['rows']) == 0:
                 return gone(
-                    _("Could not find the database on the server.")
+                    _('Could not find the database on the server.')
                 )
 
             data['old_name'] = (rset['rows'][0])['name']
@@ -594,9 +645,8 @@ class DatabaseView(PGChildNodeView):
 
             if not status:
                 current_app.logger.error(
-                    "Could not connected to database(#{0}).\nError: {1}".format(
-                        did, errmsg
-                    )
+                    'Could not connected to database(#{0}).\n'
+                    'Error: {1}'.format(did, errmsg)
                 )
                 return internal_server_error(errmsg)
 
@@ -783,9 +833,10 @@ class DatabaseView(PGChildNodeView):
                 )
 
         SQL_acl = render_template(
-                    "/".join([self.template_path, 'grant.sql']),
-                    data=data, conn=self.conn
-                )
+            "/".join([self.template_path, 'grant.sql']),
+            data=data,
+            conn=self.conn
+        )
 
         SQL = render_template(
             "/".join([self.template_path, 'create.sql']),
@@ -859,22 +910,24 @@ class DatabaseView(PGChildNodeView):
         otherwise it will return statistics for all the databases in that
         server.
         """
-        last_system_oid = 0 if self.blueprint.show_system_objects else \
-            (self.manager.db_info[self.manager.did])['datlastsysoid'] \
-            if self.manager.db_info is not None and \
-            self.manager.did in self.manager.db_info else 0
+        last_system_oid = self.retrieve_last_system_oid()
 
         db_disp_res = None
         params = None
         if self.manager and self.manager.db_res:
-            db_disp_res = ", ".join(['%s'] * len(self.manager.db_res.split(',')))
+            db_disp_res = ", ".join(
+                ['%s'] * len(self.manager.db_res.split(','))
+            )
             params = tuple(self.manager.db_res.split(','))
 
         conn = self.manager.connection()
         status, res = conn.execute_dict(render_template(
             "/".join([self.template_path, 'stats.sql']),
-            did=did, conn=conn, last_system_oid=last_system_oid, db_restrictions=db_disp_res
-            ),params
+            did=did,
+            conn=conn,
+            last_system_oid=last_system_oid,
+            db_restrictions=db_disp_res),
+            params
         )
 
         if not status:
@@ -970,7 +1023,7 @@ class DatabaseView(PGChildNodeView):
             sid: Server ID
             did: Database ID
         """
-        dependents_result = self.get_dependents(self.conn, did) if\
+        dependents_result = self.get_dependents(self.conn, did) if \
             self.conn.connected() else []
         return ajax_response(
             response=dependents_result,
@@ -988,7 +1041,7 @@ class DatabaseView(PGChildNodeView):
             sid: Server ID
             did: Database ID
         """
-        dependencies_result = self.get_dependencies(self.conn, did) if\
+        dependencies_result = self.get_dependencies(self.conn, did) if \
             self.conn.connected() else []
         return ajax_response(
             response=dependencies_result,
