@@ -10,7 +10,7 @@
 """A blueprint module implementing the dashboard frame."""
 from functools import wraps
 from flask import render_template, url_for, Response, g
-from flask_babel import gettext
+from flask_babelex import gettext
 from flask_security import login_required
 from pgadmin.utils import PgAdminModule
 from pgadmin.utils.ajax import make_response as ajax_response,\
@@ -61,7 +61,8 @@ class DashboardModule(PgAdminModule):
                 isPrivate=False,
                 limit=1,
                 isIframe=False,
-                canHide=True).__dict__
+                canHide=True
+            ).__dict__
         ]
 
     def register_preferences(self):
@@ -70,8 +71,9 @@ class DashboardModule(PgAdminModule):
         Register preferences for this module.
         """
         # Register options for the PG and PPAS help paths
-        self.dashboard_preference = Preferences('dashboards',
-                                                gettext('Dashboards'))
+        self.dashboard_preference = Preferences(
+            'dashboards', gettext('Dashboards')
+        )
 
         self.session_stats_refresh = self.dashboard_preference.register(
             'dashboards', 'session_stats_refresh',
@@ -113,6 +115,22 @@ class DashboardModule(PgAdminModule):
             help_str=gettext('The number of seconds between graph samples.')
         )
 
+        self.display_graphs = self.dashboard_preference.register(
+            'display', 'show_graphs',
+            gettext("Show graphs?"), 'boolean', True,
+            category_label=gettext('Display'),
+            help_str=gettext('If set to True, graphs '
+                             'will be displayed on dashboards.')
+        )
+
+        self.display_server_activity = self.dashboard_preference.register(
+            'display', 'show_activity',
+            gettext("Show activity?"), 'boolean', True,
+            category_label=gettext('Display'),
+            help_str=gettext('If set to True, activity tables '
+                             'will be displayed on dashboards.')
+        )
+
     def get_exposed_url_endpoints(self):
         """
         Returns:
@@ -149,6 +167,7 @@ class DashboardModule(PgAdminModule):
             'dashboard.get_config_by_server_id',
         ]
 
+
 blueprint = DashboardModule(MODULE_NAME, __name__)
 
 
@@ -168,11 +187,13 @@ def check_precondition(f):
             kwargs['sid']
         )
 
+        stats_type = ('activity', 'prepared', 'locks', 'config')
+
         # Below check handle the case where existing server is deleted
         # by user and python server will raise exception if this check
         # is not introduce.
         if g.manager is None:
-            if f.__name__ in ['activity', 'prepared', 'locks', 'config']:
+            if f.__name__ in stats_type:
                 return precondition_required(
                     gettext("Please connect to the selected server"
                             " to view the table.")
@@ -187,7 +208,7 @@ def check_precondition(f):
 
         # If DB not connected then return error to browser
         if not g.conn.connected():
-            if f.__name__ in ['activity', 'prepared', 'locks', 'config']:
+            if f.__name__ in stats_type:
                 return precondition_required(
                     gettext("Please connect to the selected server"
                             " to view the table.")
@@ -202,7 +223,7 @@ def check_precondition(f):
             db_conn = g.manager.connection(did=kwargs['did'])
             # If the selected DB not connected then return error to browser
             if not db_conn.connected():
-                if f.__name__ in ['activity', 'prepared', 'locks', 'config']:
+                if f.__name__ in stats_type:
                     return precondition_required(
                         gettext("Please connect to the selected database"
                                 " to view the table.")
@@ -220,8 +241,7 @@ def check_precondition(f):
         # Include server_type in template_path when server_type is gpdb
         g.template_path = 'dashboard/sql/' + (
             '#{0}#{1}#'.format(g.server_type, g.version)
-            if g.server_type == 'gpdb' else
-            '#{0}#'.format(g.version)
+            if g.server_type == 'gpdb' else '#{0}#'.format(g.version)
         )
 
         return f(*args, **kwargs)
@@ -233,10 +253,14 @@ def check_precondition(f):
 @login_required
 def script():
     """render the required javascript"""
-    return Response(response=render_template("dashboard/js/dashboard.js",
-                                             _=gettext),
-                    status=200,
-                    mimetype="application/javascript")
+    return Response(
+        response=render_template(
+            "dashboard/js/dashboard.js",
+            _=gettext
+        ),
+        status=200,
+        mimetype="application/javascript"
+    )
 
 
 @blueprint.route('/', endpoint='index')
@@ -254,6 +278,7 @@ def index(sid=None, did=None):
 
     """
     rates = {}
+    settings = {}
 
     prefs = Preferences.module('dashboards')
 
@@ -278,21 +303,32 @@ def index(sid=None, did=None):
     rates['to_stats_refresh'] = to_stats_refresh_pref.get()
     bio_stats_refresh_pref = prefs.preference('bio_stats_refresh')
     rates['bio_stats_refresh'] = bio_stats_refresh_pref.get()
+    # Whether to display graphs and server activity preferences
+    show_graphs_pref = prefs.preference('show_graphs')
+    settings['show_graphs'] = show_graphs_pref.get()
+    show_activity_pref = prefs.preference('show_activity')
+    settings['show_activity'] = show_activity_pref.get()
 
     # Show the appropriate dashboard based on the identifiers passed to us
     if sid is None and did is None:
         return render_template('/dashboard/welcome_dashboard.html')
     if did is None:
-        return render_template('/dashboard/server_dashboard.html',
-                               sid=sid,
-                               rates=rates,
-                               version=g.version)
+        return render_template(
+            '/dashboard/server_dashboard.html',
+            sid=sid,
+            rates=rates,
+            version=g.version,
+            settings=settings
+        )
     else:
-        return render_template('/dashboard/database_dashboard.html',
-                               sid=sid,
-                               did=did,
-                               rates=rates,
-                               version=g.version)
+        return render_template(
+            '/dashboard/database_dashboard.html',
+            sid=sid,
+            did=did,
+            rates=rates,
+            version=g.version,
+            settings=settings
+        )
 
 
 def get_data(sid, did, template):
@@ -327,7 +363,8 @@ def get_data(sid, did, template):
 
 @blueprint.route('/session_stats/', endpoint='session_stats')
 @blueprint.route(
-    '/session_stats/<int:sid>', endpoint='get_session_stats_by_sever_id')
+    '/session_stats/<int:sid>', endpoint='get_session_stats_by_sever_id'
+)
 @blueprint.route(
     '/session_stats/<int:sid>/<int:did>',
     endpoint='get_session_stats_by_database_id'
@@ -362,7 +399,8 @@ def tps_stats(sid=None, did=None):
 @blueprint.route('/ti_stats/', endpoint='ti_stats')
 @blueprint.route('/ti_stats/<int:sid>', endpoint='ti_stats_by_server_id')
 @blueprint.route(
-    '/ti_stats/<int:sid>/<int:did>', endpoint='ti_stats_by_database_id')
+    '/ti_stats/<int:sid>/<int:did>', endpoint='ti_stats_by_database_id'
+)
 @login_required
 @check_precondition
 def ti_stats(sid=None, did=None):
@@ -377,7 +415,8 @@ def ti_stats(sid=None, did=None):
 @blueprint.route('/to_stats/', endpoint='to_stats')
 @blueprint.route('/to_stats/<int:sid>', endpoint='to_stats_by_server_id')
 @blueprint.route(
-    '/to_stats/<int:sid>/<int:did>', endpoint='to_stats_by_database_id')
+    '/to_stats/<int:sid>/<int:did>', endpoint='to_stats_by_database_id'
+)
 @login_required
 @check_precondition
 def to_stats(sid=None, did=None):
@@ -392,7 +431,8 @@ def to_stats(sid=None, did=None):
 @blueprint.route('/bio_stats/', endpoint='bio_stats')
 @blueprint.route('/bio_stats/<int:sid>', endpoint='bio_stats_by_server_id')
 @blueprint.route(
-    '/bio_stats/<int:sid>/<int:did>', endpoint='bio_stats_by_database_id')
+    '/bio_stats/<int:sid>/<int:did>', endpoint='bio_stats_by_database_id'
+)
 @login_required
 @check_precondition
 def bio_stats(sid=None, did=None):
@@ -407,7 +447,8 @@ def bio_stats(sid=None, did=None):
 @blueprint.route('/activity/', endpoint='activity')
 @blueprint.route('/activity/<int:sid>', endpoint='get_activity_by_server_id')
 @blueprint.route(
-    '/activity/<int:sid>/<int:did>', endpoint='get_activity_by_database_id')
+    '/activity/<int:sid>/<int:did>', endpoint='get_activity_by_database_id'
+)
 @login_required
 @check_precondition
 def activity(sid=None, did=None):
@@ -422,7 +463,8 @@ def activity(sid=None, did=None):
 @blueprint.route('/locks/', endpoint='locks')
 @blueprint.route('/locks/<int:sid>', endpoint='get_locks_by_server_id')
 @blueprint.route(
-    '/locks/<int:sid>/<int:did>', endpoint='get_locks_by_database_id')
+    '/locks/<int:sid>/<int:did>', endpoint='get_locks_by_database_id'
+)
 @login_required
 @check_precondition
 def locks(sid=None, did=None):
@@ -437,7 +479,8 @@ def locks(sid=None, did=None):
 @blueprint.route('/prepared/', endpoint='prepared')
 @blueprint.route('/prepared/<int:sid>', endpoint='get_prepared_by_server_id')
 @blueprint.route(
-    '/prepared/<int:sid>/<int:did>', endpoint='get_prepared_by_database_id')
+    '/prepared/<int:sid>/<int:did>', endpoint='get_prepared_by_database_id'
+)
 @login_required
 @check_precondition
 def prepared(sid=None, did=None):
@@ -488,6 +531,7 @@ def cancel_query(sid=None, did=None, pid=None):
         status=200
     )
 
+
 @blueprint.route(
     '/terminate_session/<int:sid>/<int:pid>', methods=['DELETE']
 )
