@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -10,8 +10,8 @@
 """A blueprint module providing utility functions for the application."""
 
 import pgadmin.utils.driver as driver
-from flask import url_for, render_template, Response
-from flask_babel import gettext as _
+from flask import url_for, render_template, Response, request
+from flask_babelex import gettext
 from pgadmin.utils import PgAdminModule
 from pgadmin.utils.preferences import Preferences
 
@@ -22,18 +22,20 @@ MODULE_NAME = 'misc'
 
 class MiscModule(PgAdminModule):
     def get_own_javascripts(self):
-        return [{
-            'name': 'pgadmin.misc.explain',
-            'path': url_for('misc.index') + 'explain/explain',
-            'preloaded': False
-        }, {
-            'name': 'snap.svg',
-            'path': url_for(
-                'misc.static', filename='explain/vendor/snap.svg/' + (
-                    'snap.svg' if config.DEBUG else 'snap.svg-min'
-                )),
-            'preloaded': False
-        }]
+        return [
+            {
+                'name': 'pgadmin.misc.explain',
+                'path': url_for('misc.index') + 'explain/explain',
+                'preloaded': False
+            }, {
+                'name': 'snap.svg',
+                'path': url_for(
+                    'misc.static', filename='explain/vendor/snap.svg/' + (
+                        'snap.svg' if config.DEBUG else 'snap.svg-min'
+                    )),
+                'preloaded': False
+            }
+        ]
 
     def get_own_stylesheets(self):
         stylesheets = []
@@ -46,18 +48,24 @@ class MiscModule(PgAdminModule):
         """
         Register preferences for this module.
         """
-        self.misc_preference = Preferences('miscellaneous', _('Miscellaneous'))
+        self.misc_preference = Preferences(
+            'miscellaneous', gettext('Miscellaneous')
+        )
 
         lang_options = []
         for lang in config.LANGUAGES:
-            lang_options.append({'label': config.LANGUAGES[lang],
-                                 'value': lang})
+            lang_options.append(
+                {
+                    'label': config.LANGUAGES[lang],
+                    'value': lang
+                }
+            )
 
         # Register options for the User language settings
         self.misc_preference.register(
             'miscellaneous', 'user_language',
-            _("User language"), 'options', 'en',
-            category_label=_('User language'),
+            gettext("User language"), 'options', 'en',
+            category_label=gettext('User language'),
             options=lang_options
         )
 
@@ -102,8 +110,24 @@ def explain_js():
     """
     return Response(
         response=render_template(
-            "explain/js/explain.js", _=_
+            "explain/js/explain.js",
+            _=gettext
         ),
         status=200,
         mimetype="application/javascript"
     )
+
+
+##########################################################################
+# A special URL used to shutdown the server
+##########################################################################
+@blueprint.route("/shutdown", methods=('get', 'post'))
+def shutdown():
+    if config.SERVER_MODE is not True:
+        func = request.environ.get('werkzeug.server.shutdown')
+        if func is None:
+            raise RuntimeError('Not running with the Werkzeug Server')
+        func()
+        return 'SHUTDOWN'
+    else:
+        return ''
