@@ -13,7 +13,7 @@ import 'codemirror/addon/search/searchcursor';
 import 'codemirror/addon/search/jump-to-line';
 import 'codemirror/addon/edit/matchbrackets';
 import 'codemirror/addon/edit/closebrackets';
-import 'codemirror/addon/comment/comment'
+import 'codemirror/addon/comment/comment';
 import '../js/codemirror/addon/fold/pgadmin-sqlfoldcode';
 
 export default CodeMirror;
\ No newline at end of file
