@@ -12,7 +12,7 @@
 import simplejson as json
 
 from flask import url_for, Response, render_template, request, current_app
-from flask_babel import gettext as _
+from flask_babelex import gettext as _
 from flask_security import login_required
 from pgadmin.misc.bgprocess.processes import BatchProcess, IProcessDesc
 from pgadmin.utils import PgAdminModule, html
@@ -120,8 +120,8 @@ class Message(IProcessDesc):
         if self.data['op'] == "REINDEX":
             if 'schema' in self.data and self.data['schema']:
                 if 'primary_key' in self.data or\
-                                'unique_constraint' in self.data or\
-                                'index' in self.data:
+                    'unique_constraint' in self.data or\
+                        'index' in self.data:
                     return _('REINDEX INDEX')
                 else:
                     return _('REINDEX TABLE')
@@ -236,6 +236,7 @@ def create_maintenance_job(sid, did):
             cmd=utility, args=args
         )
         manager.export_password_env(p.id)
+        p.set_env_variables(server)
         p.start()
         jid = p.id
     except Exception as e:
@@ -248,5 +249,6 @@ def create_maintenance_job(sid, did):
 
     # Return response
     return make_json_response(
-        data={'job_id': jid, 'status': True, 'info': 'Maintenance job created.'}
+        data={'job_id': jid, 'status': True,
+              'info': 'Maintenance job created.'}
     )
