@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -16,7 +16,7 @@ except ImportError:
     from ordereddict import OrderedDict
 import six
 from flask import render_template
-from flask_babel import gettext
+from flask_babelex import gettext
 from pgadmin.utils.ajax import forbidden
 from pgadmin.utils.driver import get_driver
 
@@ -67,7 +67,8 @@ class ObjectRegistry(ABCMeta):
             return (ObjectRegistry.registry[name])(**kwargs)
 
         raise NotImplementedError(
-            gettext("This feature has not been implemented for object type '{0}'!").format(name)
+            gettext("This feature has not been implemented for object "
+                    "type '{0}'.").format(name)
         )
 
 
@@ -103,7 +104,9 @@ class BaseCommand(object):
             **kwargs : N number of parameters
         """
 
-        # Save the server id and database id, namespace id, object id
+        # Save the server group id, server id and database id, namespace id,
+        # object id
+        self.sgid = kwargs['sgid'] if 'sgid' in kwargs else None
         self.sid = kwargs['sid'] if 'sid' in kwargs else None
         self.did = kwargs['did'] if 'did' in kwargs else None
 
@@ -138,6 +141,10 @@ class SQLFilter(object):
       - This method removes the filter applied.
     * validate_filter(row_filter)
       - This method validates the given filter.
+    * get_data_sorting()
+      - This method returns columns for data sorting
+    * set_data_sorting()
+      - This method saves columns for data sorting
     """
 
     def __init__(self, **kwargs):
@@ -157,7 +164,8 @@ class SQLFilter(object):
         self.sid = kwargs['sid']
         self.did = kwargs['did']
         self.obj_id = kwargs['obj_id']
-        self.__row_filter = kwargs['sql_filter'] if 'sql_filter' in kwargs else None
+        self.__row_filter = kwargs.get('sql_filter', None)
+        self.__dara_sorting = kwargs.get('data_sorting', None)
 
         manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(self.sid)
         conn = manager.connection(did=self.did)
@@ -167,7 +175,10 @@ class SQLFilter(object):
 
         if conn.connected():
             # Fetch the Namespace Name and object Name
-            query = render_template("/".join([self.sql_path, 'objectname.sql']), obj_id=self.obj_id)
+            query = render_template(
+                "/".join([self.sql_path, 'objectname.sql']),
+                obj_id=self.obj_id
+            )
 
             status, result = conn.execute_dict(query)
             if not status:
@@ -176,7 +187,10 @@ class SQLFilter(object):
             self.nsp_name = result['rows'][0]['nspname']
             self.object_name = result['rows'][0]['relname']
         else:
-            raise Exception(gettext('Not connected to server or connection with the server has been closed.'))
+            raise Exception(gettext(
+                'Not connected to server or connection with the server '
+                'has been closed.')
+            )
 
     def get_filter(self):
         """
@@ -200,20 +214,41 @@ class SQLFilter(object):
 
         return status, msg
 
+    def get_data_sorting(self):
+        """
+        This function returns the filter.
+        """
+        if self.__dara_sorting and len(self.__dara_sorting) > 0:
+            return self.__dara_sorting
+        return None
+
+    def set_data_sorting(self, data_filter):
+        """
+        This function validates the filter and set the
+        given filter to member variable.
+        """
+        self.__dara_sorting = data_filter['data_sorting']
+
     def is_filter_applied(self):
         """
         This function returns True if filter is applied else False.
         """
+        is_filter_applied = True
         if self.__row_filter is None or self.__row_filter == '':
-            return False
+            is_filter_applied = False
 
-        return True
+        if not is_filter_applied:
+            if self.__dara_sorting and len(self.__dara_sorting) > 0:
+                is_filter_applied = True
+
+        return is_filter_applied
 
     def remove_filter(self):
         """
         This function remove the filter by setting value to None.
         """
         self.__row_filter = None
+        self.__dara_sorting = None
 
     def append_filter(self, row_filter):
         """
@@ -248,8 +283,10 @@ class SQLFilter(object):
         conn = manager.connection(did=self.did)
 
         if conn.connected():
-            sql = render_template("/".join([self.sql_path, 'validate.sql']),
-                                  nsp_name=self.nsp_name, object_name=self.object_name, row_filter=row_filter)
+            sql = render_template(
+                "/".join([self.sql_path, 'validate.sql']),
+                nsp_name=self.nsp_name, object_name=self.object_name,
+                row_filter=row_filter)
 
             status, result = conn.execute_scalar(sql)
             if not status:
@@ -262,6 +299,7 @@ class FetchedRowTracker(object):
     """
     Keeps track of fetched row count.
     """
+
     def __init__(self, **kwargs):
         self.fetched_rows = 0
 
@@ -285,7 +323,8 @@ class GridCommand(BaseCommand, SQLFilter, FetchedRowTracker):
       - Derived class can implement there own logic to get the primary keys.
 
     * save()
-      - Derived class can implement there own logic to save the data into the database.
+      - Derived class can implement there own logic to save the data into the
+      database.
 
     * set_limit(limit)
       - This method sets the limit for SQL query
@@ -311,14 +350,62 @@ class GridCommand(BaseCommand, SQLFilter, FetchedRowTracker):
         self.cmd_type = kwargs['cmd_type'] if 'cmd_type' in kwargs else None
         self.limit = -1
 
-        if self.cmd_type == VIEW_FIRST_100_ROWS or self.cmd_type == VIEW_LAST_100_ROWS:
+        if self.cmd_type in (VIEW_FIRST_100_ROWS, VIEW_LAST_100_ROWS):
             self.limit = 100
 
     def get_primary_keys(self, *args, **kwargs):
         return None, None
 
+    def get_all_columns_with_order(self, default_conn):
+        """
+        Responsible for fetching columns from given object
+
+        Args:
+            default_conn: Connection object
+
+        Returns:
+            all_sorted_columns: Columns which are already sorted which will
+                         be used to populate the Grid in the dialog
+            all_columns: List of all the column for given object which will
+                         be used to fill columns options
+        """
+        driver = get_driver(PG_DEFAULT_DRIVER)
+        if default_conn is None:
+            manager = driver.connection_manager(self.sid)
+            conn = manager.connection(did=self.did, conn_id=self.conn_id)
+        else:
+            conn = default_conn
+
+        all_sorted_columns = []
+        data_sorting = self.get_data_sorting()
+        all_columns = []
+        if conn.connected():
+            # Fetch the rest of the column names
+            query = render_template(
+                "/".join([self.sql_path, 'get_columns.sql']),
+                obj_id=self.obj_id
+            )
+            status, result = conn.execute_dict(query)
+            if not status:
+                raise Exception(result)
+
+            for row in result['rows']:
+                all_columns.append(row['attname'])
+        else:
+            raise Exception(
+                gettext('Not connected to server or connection with the '
+                        'server has been closed.')
+            )
+        # If user has custom data sorting then pass as it as it is
+        if data_sorting and len(data_sorting) > 0:
+            all_sorted_columns = data_sorting
+
+        return all_sorted_columns, all_columns
+
     def save(self, changed_data, default_conn=None):
-        return forbidden(errmsg=gettext("Data cannot be saved for the current object."))
+        return forbidden(
+            errmsg=gettext("Data cannot be saved for the current object.")
+        )
 
     def get_limit(self):
         """
@@ -334,6 +421,17 @@ class GridCommand(BaseCommand, SQLFilter, FetchedRowTracker):
         """
         self.limit = limit
 
+    def get_pk_order(self):
+        """
+        This function gets the order required for primary keys
+        """
+        if self.cmd_type in (VIEW_FIRST_100_ROWS, VIEW_ALL_ROWS):
+            return 'asc'
+        elif self.cmd_type == VIEW_LAST_100_ROWS:
+            return 'desc'
+        else:
+            return None
+
 
 class TableCommand(GridCommand):
     """
@@ -364,16 +462,30 @@ class TableCommand(GridCommand):
         # Fetch the primary keys for the table
         pk_names, primary_keys = self.get_primary_keys(default_conn)
 
+        # Fetch OIDs status
+        has_oids = self.has_oids(default_conn)
+
         sql_filter = self.get_filter()
+        data_sorting = self.get_data_sorting()
 
         if sql_filter is None:
-            sql = render_template("/".join([self.sql_path, 'objectquery.sql']), object_name=self.object_name,
-                                  nsp_name=self.nsp_name, pk_names=pk_names, cmd_type=self.cmd_type,
-                                  limit=self.limit, primary_keys=primary_keys)
+            sql = render_template(
+                "/".join([self.sql_path, 'objectquery.sql']),
+                object_name=self.object_name,
+                nsp_name=self.nsp_name, pk_names=pk_names,
+                cmd_type=self.cmd_type, limit=self.limit,
+                primary_keys=primary_keys, has_oids=has_oids,
+                data_sorting=data_sorting
+            )
         else:
-            sql = render_template("/".join([self.sql_path, 'objectquery.sql']), object_name=self.object_name,
-                                  nsp_name=self.nsp_name, pk_names=pk_names, cmd_type=self.cmd_type,
-                                  sql_filter=sql_filter, limit=self.limit, primary_keys=primary_keys)
+            sql = render_template(
+                "/".join([self.sql_path, 'objectquery.sql']),
+                object_name=self.object_name,
+                nsp_name=self.nsp_name, pk_names=pk_names,
+                cmd_type=self.cmd_type, sql_filter=sql_filter,
+                limit=self.limit, primary_keys=primary_keys,
+                has_oids=has_oids, data_sorting=data_sorting
+            )
 
         return sql
 
@@ -394,7 +506,10 @@ class TableCommand(GridCommand):
         if conn.connected():
 
             # Fetch the primary key column names
-            query = render_template("/".join([self.sql_path, 'primary_keys.sql']), obj_id=self.obj_id)
+            query = render_template(
+                "/".join([self.sql_path, 'primary_keys.sql']),
+                obj_id=self.obj_id
+            )
 
             status, result = conn.execute_dict(query)
             if not status:
@@ -408,16 +523,115 @@ class TableCommand(GridCommand):
                 # Remove last character from the string
                 pk_names = pk_names[:-1]
         else:
-            raise Exception(gettext('Not connected to server or connection with the server has been closed.'))
+            raise Exception(
+                gettext('Not connected to server or connection with the '
+                        'server has been closed.')
+            )
 
         return pk_names, primary_keys
 
+    def get_all_columns_with_order(self, default_conn=None):
+        """
+        It is overridden method specially for Table because we all have to
+        fetch primary keys and rest of the columns both.
+
+        Args:
+            default_conn: Connection object
+
+        Returns:
+            all_sorted_columns: Sorted columns for the Grid
+            all_columns: List of columns for the select2 options
+        """
+        driver = get_driver(PG_DEFAULT_DRIVER)
+        if default_conn is None:
+            manager = driver.connection_manager(self.sid)
+            conn = manager.connection(did=self.did, conn_id=self.conn_id)
+        else:
+            conn = default_conn
+
+        all_sorted_columns = []
+        data_sorting = self.get_data_sorting()
+        all_columns = []
+        if conn.connected():
+
+            # Fetch the primary key column names
+            query = render_template(
+                "/".join([self.sql_path, 'primary_keys.sql']),
+                obj_id=self.obj_id
+            )
+
+            status, result = conn.execute_dict(query)
+            if not status:
+                raise Exception(result)
+
+            for row in result['rows']:
+                all_columns.append(row['attname'])
+                all_sorted_columns.append(
+                    {
+                        'name': row['attname'],
+                        'order': self.get_pk_order()
+                    }
+                )
+
+            # Fetch the rest of the column names
+            query = render_template(
+                "/".join([self.sql_path, 'get_columns.sql']),
+                obj_id=self.obj_id
+            )
+            status, result = conn.execute_dict(query)
+            if not status:
+                raise Exception(result)
+
+            for row in result['rows']:
+                # Only append if not already present in the list
+                if row['attname'] not in all_columns:
+                    all_columns.append(row['attname'])
+        else:
+            raise Exception(
+                gettext('Not connected to server or connection with the '
+                        'server has been closed.')
+            )
+        # If user has custom data sorting then pass as it as it is
+        if data_sorting and len(data_sorting) > 0:
+            all_sorted_columns = data_sorting
+
+        return all_sorted_columns, all_columns
+
     def can_edit(self):
         return True
 
     def can_filter(self):
         return True
 
+    def has_oids(self, default_conn=None):
+        """
+        This function checks whether the table has oids or not.
+        """
+        driver = get_driver(PG_DEFAULT_DRIVER)
+        if default_conn is None:
+            manager = driver.connection_manager(self.sid)
+            conn = manager.connection(did=self.did, conn_id=self.conn_id)
+        else:
+            conn = default_conn
+
+        if conn.connected():
+
+            # Fetch the table oids status
+            query = render_template(
+                "/".join([self.sql_path, 'has_oids.sql']), obj_id=self.obj_id)
+
+            status, has_oids = conn.execute_scalar(query)
+            if not status:
+                raise Exception(has_oids)
+
+        else:
+            raise Exception(
+                gettext('Not connected to server or connection with the '
+                        'server has been closed.')
+            )
+
+        return has_oids
+
     def save(self,
              changed_data,
              columns_info,
@@ -469,8 +683,7 @@ class TableCommand(GridCommand):
                 for each_col in columns_info:
                     if (
                         columns_info[each_col]['not_null'] and
-                        not columns_info[each_col][
-                            'has_default_val']
+                        not columns_info[each_col]['has_default_val']
                     ):
                         column_data[each_col] = None
                         column_type[each_col] =\
@@ -481,6 +694,17 @@ class TableCommand(GridCommand):
 
                 # For newly added rows
                 if of_type == 'added':
+                    # Python dict does not honour the inserted item order
+                    # So to insert data in the order, we need to make ordered
+                    # list of added index We don't need this mechanism in
+                    # updated/deleted rows as it does not matter in
+                    # those operations
+                    added_index = OrderedDict(
+                        sorted(
+                            changed_data['added_index'].items(),
+                            key=lambda x: int(x[0])
+                        )
+                    )
                     list_of_sql[of_type] = []
 
                     # When new rows are added, only changed columns data is
@@ -489,9 +713,13 @@ class TableCommand(GridCommand):
                     # of not null which is set by default.
                     column_data = {}
                     pk_names, primary_keys = self.get_primary_keys()
+                    has_oids = 'oid' in column_type
 
-                    for each_row in changed_data[of_type]:
-                        data = changed_data[of_type][each_row]['data']
+                    for each_row in added_index:
+                        # Get the row index to match with the added rows
+                        # dict key
+                        tmp_row_index = added_index[each_row]
+                        data = changed_data[of_type][tmp_row_index]['data']
                         # Remove our unique tracking key
                         data.pop(client_primary_key, None)
                         data.pop('is_row_copied', None)
@@ -501,14 +729,30 @@ class TableCommand(GridCommand):
                         # not_null=False and has no default value
                         column_data.update(data)
 
-                        sql = render_template("/".join([self.sql_path, 'insert.sql']),
-                                              data_to_be_saved=column_data,
-                                              primary_keys=None,
-                                              object_name=self.object_name,
-                                              nsp_name=self.nsp_name,
-                                              data_type=column_type,
-                                              pk_names=pk_names)
-                        list_of_sql[of_type].append({'sql': sql, 'data': data})
+                        sql = render_template(
+                            "/".join([self.sql_path, 'insert.sql']),
+                            data_to_be_saved=column_data,
+                            primary_keys=None,
+                            object_name=self.object_name,
+                            nsp_name=self.nsp_name,
+                            data_type=column_type,
+                            pk_names=pk_names,
+                            has_oids=has_oids
+                        )
+
+                        select_sql = render_template(
+                            "/".join([self.sql_path, 'select.sql']),
+                            object_name=self.object_name,
+                            nsp_name=self.nsp_name,
+                            primary_keys=primary_keys,
+                            has_oids=has_oids
+                        )
+
+                        list_of_sql[of_type].append({
+                            'sql': sql, 'data': data,
+                            'client_row': tmp_row_index,
+                            'select_sql': select_sql
+                        })
                         # Reset column data
                         column_data = {}
 
@@ -518,12 +762,14 @@ class TableCommand(GridCommand):
                     for each_row in changed_data[of_type]:
                         data = changed_data[of_type][each_row]['data']
                         pk = changed_data[of_type][each_row]['primary_keys']
-                        sql = render_template("/".join([self.sql_path, 'update.sql']),
-                                              data_to_be_saved=data,
-                                              primary_keys=pk,
-                                              object_name=self.object_name,
-                                              nsp_name=self.nsp_name,
-                                              data_type=column_type)
+                        sql = render_template(
+                            "/".join([self.sql_path, 'update.sql']),
+                            data_to_be_saved=data,
+                            primary_keys=pk,
+                            object_name=self.object_name,
+                            nsp_name=self.nsp_name,
+                            data_type=column_type
+                        )
                         list_of_sql[of_type].append({'sql': sql, 'data': data})
                         list_of_rowid.append(data.get(client_primary_key))
 
@@ -542,8 +788,9 @@ class TableCommand(GridCommand):
                             # Python3
                             # In Python2, it's already a list & We will also
                             # fetch column names using index
-                            keys = list(changed_data[of_type][each_row].keys())
-
+                            keys = list(
+                                changed_data[of_type][each_row].keys()
+                            )
                             no_of_keys = len(keys)
                             is_first = False
                     # Map index with column name for each row
@@ -552,45 +799,94 @@ class TableCommand(GridCommand):
                             # Set primary key with label & delete index based
                             # mapped key
                             try:
-                                row[changed_data['columns'][int(k)]['name']] = v
+                                row[changed_data['columns']
+                                    [int(k)]['name']] = v
                             except ValueError:
                                 continue
                             del row[k]
 
-                    sql = render_template("/".join([self.sql_path, 'delete.sql']),
-                                          data=rows_to_delete,
-                                          primary_key_labels=keys,
-                                          no_of_keys=no_of_keys,
-                                          object_name=self.object_name,
-                                          nsp_name=self.nsp_name)
+                    sql = render_template(
+                        "/".join([self.sql_path, 'delete.sql']),
+                        data=rows_to_delete,
+                        primary_key_labels=keys,
+                        no_of_keys=no_of_keys,
+                        object_name=self.object_name,
+                        nsp_name=self.nsp_name
+                    )
                     list_of_sql[of_type].append({'sql': sql, 'data': {}})
 
             for opr, sqls in list_of_sql.items():
                 for item in sqls:
                     if item['sql']:
-                        status, res = conn.execute_void(
-                            item['sql'], item['data'])
-                        rows_affected = conn.rows_affected()
+                        row_added = None
 
-                        # store the result of each query in dictionary
-                        query_res[count] = {'status': status, 'result': res,
-                                            'sql': sql, 'rows_affected': rows_affected}
+                        # Fetch oids/primary keys
+                        if 'select_sql' in item and item['select_sql']:
+                            status, res = conn.execute_dict(
+                                item['sql'], item['data'])
+                        else:
+                            status, res = conn.execute_void(
+                                item['sql'], item['data'])
 
                         if not status:
                             conn.execute_void('ROLLBACK;')
-                            # If we roll backed every thing then update the message for
-                            # each sql query.
+                            # If we roll backed every thing then update the
+                            # message for each sql query.
                             for val in query_res:
                                 if query_res[val]['status']:
-                                    query_res[val]['result'] = 'Transaction ROLLBACK'
+                                    query_res[val]['result'] = \
+                                        'Transaction ROLLBACK'
 
                             # If list is empty set rowid to 1
                             try:
-                                _rowid = list_of_rowid[count] if list_of_rowid else 1
+                                if list_of_rowid:
+                                    _rowid = list_of_rowid[count]
+                                else:
+                                    _rowid = 1
                             except Exception:
                                 _rowid = 0
 
                             return status, res, query_res, _rowid
+
+                        # Select added row from the table
+                        if 'select_sql' in item:
+                            status, sel_res = conn.execute_dict(
+                                item['select_sql'], res['rows'][0])
+
+                            if not status:
+                                conn.execute_void('ROLLBACK;')
+                                # If we roll backed every thing then update
+                                # the message for each sql query.
+                                for val in query_res:
+                                    if query_res[val]['status']:
+                                        query_res[val]['result'] = \
+                                            'Transaction ROLLBACK'
+
+                                # If list is empty set rowid to 1
+                                try:
+                                    if list_of_rowid:
+                                        _rowid = list_of_rowid[count]
+                                    else:
+                                        _rowid = 1
+                                except Exception:
+                                    _rowid = 0
+
+                                return status, sel_res, query_res, _rowid
+
+                            if 'rows' in sel_res and len(sel_res['rows']) > 0:
+                                row_added = {
+                                    item['client_row']: sel_res['rows'][0]}
+
+                        rows_affected = conn.rows_affected()
+
+                        # store the result of each query in dictionary
+                        query_res[count] = {
+                            'status': status,
+                            'result': None if row_added else res,
+                            'sql': sql, 'rows_affected': rows_affected,
+                            'row_added': row_added
+                        }
+
                         count += 1
 
             # Commit the transaction if there is no error found
@@ -625,15 +921,23 @@ class ViewCommand(GridCommand):
         to fetch the data for the specified view
         """
         sql_filter = self.get_filter()
+        data_sorting = self.get_data_sorting()
 
         if sql_filter is None:
-            sql = render_template("/".join([self.sql_path, 'objectquery.sql']), object_name=self.object_name,
-                                  nsp_name=self.nsp_name, cmd_type=self.cmd_type,
-                                  limit=self.limit)
+            sql = render_template(
+                "/".join([self.sql_path, 'objectquery.sql']),
+                object_name=self.object_name,
+                nsp_name=self.nsp_name, cmd_type=self.cmd_type,
+                limit=self.limit, data_sorting=data_sorting
+            )
         else:
-            sql = render_template("/".join([self.sql_path, 'objectquery.sql']), object_name=self.object_name,
-                                  nsp_name=self.nsp_name, cmd_type=self.cmd_type,
-                                  sql_filter=sql_filter, limit=self.limit)
+            sql = render_template(
+                "/".join([self.sql_path, 'objectquery.sql']),
+                object_name=self.object_name,
+                nsp_name=self.nsp_name, cmd_type=self.cmd_type,
+                sql_filter=sql_filter, limit=self.limit,
+                data_sorting=data_sorting
+            )
 
         return sql
 
@@ -680,15 +984,23 @@ class ForeignTableCommand(GridCommand):
         to fetch the data for the specified foreign table
         """
         sql_filter = self.get_filter()
+        data_sorting = self.get_data_sorting()
 
         if sql_filter is None:
-            sql = render_template("/".join([self.sql_path, 'objectquery.sql']), object_name=self.object_name,
-                                  nsp_name=self.nsp_name, cmd_type=self.cmd_type,
-                                  limit=self.limit)
+            sql = render_template(
+                "/".join([self.sql_path, 'objectquery.sql']),
+                object_name=self.object_name,
+                nsp_name=self.nsp_name, cmd_type=self.cmd_type,
+                limit=self.limit, data_sorting=data_sorting
+            )
         else:
-            sql = render_template("/".join([self.sql_path, 'objectquery.sql']), object_name=self.object_name,
-                                  nsp_name=self.nsp_name, cmd_type=self.cmd_type,
-                                  sql_filter=sql_filter, limit=self.limit)
+            sql = render_template(
+                "/".join([self.sql_path, 'objectquery.sql']),
+                object_name=self.object_name,
+                nsp_name=self.nsp_name, cmd_type=self.cmd_type,
+                sql_filter=sql_filter, limit=self.limit,
+                data_sorting=data_sorting
+            )
 
         return sql
 
@@ -725,15 +1037,23 @@ class CatalogCommand(GridCommand):
         to fetch the data for the specified catalog object
         """
         sql_filter = self.get_filter()
+        data_sorting = self.get_data_sorting()
 
         if sql_filter is None:
-            sql = render_template("/".join([self.sql_path, 'objectquery.sql']), object_name=self.object_name,
-                                  nsp_name=self.nsp_name, cmd_type=self.cmd_type,
-                                  limit=self.limit)
+            sql = render_template(
+                "/".join([self.sql_path, 'objectquery.sql']),
+                object_name=self.object_name,
+                nsp_name=self.nsp_name, cmd_type=self.cmd_type,
+                limit=self.limit, data_sorting=data_sorting
+            )
         else:
-            sql = render_template("/".join([self.sql_path, 'objectquery.sql']), object_name=self.object_name,
-                                  nsp_name=self.nsp_name, cmd_type=self.cmd_type,
-                                  sql_filter=sql_filter, limit=self.limit)
+            sql = render_template(
+                "/".join([self.sql_path, 'objectquery.sql']),
+                object_name=self.object_name,
+                nsp_name=self.nsp_name, cmd_type=self.cmd_type,
+                sql_filter=sql_filter, limit=self.limit,
+                data_sorting=data_sorting
+            )
 
         return sql
 
@@ -758,13 +1078,16 @@ class QueryToolCommand(BaseCommand, FetchedRowTracker):
         BaseCommand.__init__(self, **kwargs)
         FetchedRowTracker.__init__(self, **kwargs)
 
-        self.conn_id = None
+        self.conn_id = kwargs['conn_id'] if 'conn_id' in kwargs else None
         self.auto_rollback = False
         self.auto_commit = True
 
     def get_sql(self, default_conn=None):
         return None
 
+    def get_all_columns_with_order(self, default_conn=None):
+        return None
+
     def can_edit(self):
         return False
 
