@@ -7,10 +7,13 @@
 #
 ##########################################################################
 
+import os
+import sys
 from collections import defaultdict
 from operator import attrgetter
 
 from flask import Blueprint, current_app
+from flask_babelex import gettext
 
 from .paths import get_storage_directory
 from .preferences import Preferences
@@ -152,9 +155,6 @@ class PgAdminModule(Blueprint):
         return res
 
 
-import os
-import sys
-
 IS_PY2 = (sys.version_info[0] == 2)
 IS_WIN = (os.name == 'nt')
 
@@ -184,6 +184,7 @@ def file_quote(_p):
             return _p.encode(fs_encoding)
     return _p
 
+
 if IS_WIN:
     import ctypes
     from ctypes import wintypes
@@ -198,7 +199,7 @@ if IS_WIN:
             if n == 0:
                 return None
 
-            buf= ctypes.create_unicode_buffer(u'\0'*n)
+            buf = ctypes.create_unicode_buffer(u'\0' * n)
             ctypes.windll.kernel32.GetEnvironmentVariableW(name, buf, n)
 
             return buf.value
@@ -280,3 +281,37 @@ def get_complete_file_path(file):
 
     return file if os.path.isfile(file) else None
 
+
+# Shortcut configuration for Accesskey
+ACCESSKEY_FIELDS = [
+    {
+        'name': 'key',
+        'type': 'keyCode',
+        'label': gettext('Key')
+    }
+]
+
+# Shortcut configuration
+SHORTCUT_FIELDS = [
+    {
+        'name': 'key',
+        'type': 'keyCode',
+        'label': gettext('Key')
+    },
+    {
+        'name': 'shift',
+        'type': 'checkbox',
+        'label': gettext('Shift')
+    },
+
+    {
+        'name': 'control',
+        'type': 'checkbox',
+        'label': gettext('Ctrl')
+    },
+    {
+        'name': 'alt',
+        'type': 'checkbox',
+        'label': gettext('Alt/Option')
+    }
+]
