@@ -87,7 +87,7 @@ if pgadmin_credentials:
                 'login_password'])
 
 # Execute the setup file
-exec (open("setup.py").read())
+exec(open("setup.py").read())
 
 # Get the config database schema version. We store this in pgadmin.model
 # as it turns out that putting it in the config files isn't a great idea
@@ -107,6 +107,7 @@ config.CONSOLE_LOG_LEVEL = WARNING
 app = create_app()
 app.config['WTF_CSRF_ENABLED'] = False
 app.PGADMIN_KEY = ''
+app.config.update({'SESSION_COOKIE_DOMAIN': None})
 test_client = app.test_client()
 driver = None
 app_starter = None
@@ -120,10 +121,11 @@ unit_test.runner.TextTestResult.addSuccess = test_utils.add_success
 scenarios.apply_scenario = test_utils.apply_scenario
 
 
-def get_suite(module_list, test_server, test_app_client):
+def get_suite(module_list, test_server, test_app_client, server_information):
     """
      This function add the tests to test suite and return modified test suite
       variable.
+    :param server_information:
     :param module_list: test module list
     :type module_list: list
     :param test_server: server details
@@ -148,6 +150,7 @@ def get_suite(module_list, test_server, test_app_client):
         obj.setTestClient(test_app_client)
         obj.setTestServer(test_server)
         obj.setDriver(driver)
+        obj.setServerInformation(server_information)
         scenario = scenarios.generate_scenarios(obj)
         pgadmin_suite.addTests(scenario)
 
@@ -210,10 +213,15 @@ def add_arguments():
     """
 
     parser = argparse.ArgumentParser(description='Test suite for pgAdmin4')
-    parser.add_argument('--pkg', help='Executes the test cases of particular'
-                                      ' package and subpackages')
-    parser.add_argument('--exclude', help='Skips execution of the test '
-                                          'cases of particular package and sub-packages')
+    parser.add_argument(
+        '--pkg',
+        help='Executes the test cases of particular package and subpackages'
+    )
+    parser.add_argument(
+        '--exclude',
+        help='Skips execution of the test cases of particular package and '
+             'sub-packages'
+    )
     arg = parser.parse_args()
 
     return arg
@@ -314,12 +322,12 @@ if __name__ == '__main__':
         signal.signal(getattr(signal, sig), sig_handler)
 
     # Set basic logging configuration for log file
-    logging.basicConfig(level=logging.DEBUG,
-                        format='%(asctime)s:%(levelname)s:%(name)s:%(message)s'
-                        ,
-                        filename=CURRENT_PATH + "/" + "regression.log",
-                        filemode='w'
-                        )
+    logging.basicConfig(
+        level=logging.DEBUG,
+        format='%(asctime)s:%(levelname)s:%(name)s:%(message)s',
+        filename=CURRENT_PATH + "/" + "regression.log",
+        filemode='w'
+    )
 
     # Create logger to write log in the logger file as well as on console
     stderr_logger = logging.getLogger('STDERR')
@@ -339,12 +347,15 @@ if __name__ == '__main__':
             print("\n=============Running the test cases for '%s'============="
                   % server['name'], file=sys.stderr)
             # Create test server
-            test_utils.create_parent_server_node(server)
+            server_information = test_utils.create_parent_server_node(server)
 
-            suite = get_suite(test_module_list, server, test_client)
+            suite = get_suite(test_module_list,
+                              server,
+                              test_client,
+                              server_information)
             tests = unit_test.TextTestRunner(stream=sys.stderr,
-                                            descriptions=True,
-                                            verbosity=2).run(suite)
+                                             descriptions=True,
+                                             verbosity=2).run(suite)
 
             ran_tests, failed_cases, skipped_cases, passed_cases = \
                 get_tests_result(tests)
@@ -364,12 +375,16 @@ if __name__ == '__main__':
         if handle_cleanup:
             handle_cleanup()
 
-    print("\n==============================================================="
-          "=======", file=sys.stderr)
+    print(
+        "\n==============================================================="
+        "=======",
+        file=sys.stderr
+    )
     print("Test Result Summary", file=sys.stderr)
     print(
         "==================================================================="
-        "===\n", file=sys.stderr)
+        "===\n", file=sys.stderr
+    )
 
     test_result_json = {}
     for server_res in test_result:
@@ -404,10 +419,11 @@ if __name__ == '__main__':
             file=sys.stderr)
 
         temp_dict_for_server = {
-            server_res: {"tests_passed": [total_passed_cases, passed_cases],
-                         "tests_failed": [total_failed, failed_cases_json],
-                         "tests_skipped": [total_skipped, skipped_cases_json]
-                         }
+            server_res: {
+                "tests_passed": [total_passed_cases, passed_cases],
+                "tests_failed": [total_failed, failed_cases_json],
+                "tests_skipped": [total_skipped, skipped_cases_json]
+            }
         }
         test_result_json.update(temp_dict_for_server)
 
@@ -418,7 +434,9 @@ if __name__ == '__main__':
 
     print(
         "==================================================================="
-        "===\n", file=sys.stderr)
+        "===\n",
+        file=sys.stderr
+    )
 
     print("Please check output in file: %s/regression.log\n" % CURRENT_PATH)
 
