@@ -12,6 +12,7 @@ module.exports = {
       jQuery: 'jquery',
       _: 'underscore',
       'underscore.string': 'underscore.string',
+      'window.jQuery': 'jquery',
     }),
   ],
 
@@ -23,7 +24,7 @@ module.exports = {
         use: {
           loader: 'babel-loader',
           options: {
-            presets: ['es2015', 'react'],
+            presets: ['es2015', 'react', 'airbnb'],
           },
         },
       }, {
@@ -60,6 +61,13 @@ module.exports = {
       'alertify': path.join(__dirname, './node_modules/alertifyjs/build/alertify'),
       'jquery.event.drag': path.join(__dirname, './node_modules/slickgrid/lib/jquery.event.drag-2.2'),
       'jquery.ui': path.join(__dirname, './node_modules/slickgrid/lib/jquery-ui-1.11.3'),
+      'spectrum': path.join(__dirname, './node_modules/spectrum-colorpicker/spectrum'),
+      'bignumber': path.join(__dirname, './node_modules/bignumber.js/bignumber'),
+      'bootstrap.datetimepicker': path.join(__dirname, './node_modules/eonasdan-bootstrap-datetimepicker/build/js/bootstrap-datetimepicker.min'),
+      'bootstrap.switch': path.join(__dirname, './node_modules/bootstrap-switch/dist/js/bootstrap-switch'),
+      'backbone': path.join(__dirname, './node_modules/backbone/backbone'),
+      'backform': path.join(__dirname, './node_modules/backform/src/backform'),
+      'backgrid': path.join(__dirname, './node_modules/backgrid/lib/backgrid'),
       'sources': sourcesDir + '/js',
       'translations': regressionDir + '/javascript/fake_translations',
       'pgadmin.browser.endpoints': regressionDir + '/javascript/fake_endpoints',
@@ -70,13 +78,8 @@ module.exports = {
       'pgadmin': sourcesDir + '/js/pgadmin',
       'pgadmin.sqlfoldcode': sourcesDir + '/js/codemirror/addon/fold/pgadmin-sqlfoldcode',
       'pgadmin.alertifyjs': sourcesDir + '/js/alertify.pgadmin.defaults',
+      'pgadmin.backgrid': sourcesDir + '/js/backgrid.pgadmin',
+      'pgadmin.backform': sourcesDir + '/js/backform.pgadmin',
     },
   },
-  externals: {
-    'react/addons': true,
-    'react/lib/ReactContext': true,
-    'react/lib/ExecutionEnvironment': true,
-    'react-dom/test-utils': true,
-    'react-test-renderer/shallow': true,
-  },
 };
